
/* The US Federal Legal System:
 * 
	%join (((1 AND 2) AND 3) OR (((1 AND 4) AND 5) AND 3)) OR (6 AND 7)
	%type binary
	     1  51 218  1  50  67  290
	x100 0   1   0  0   1   1    0 Member of the Senate
	x435 0   0   1  0   0   0    1 Member of the House of Rep.
	     1   0   0  0   0   0    0 President
	     0   0   0  1   0   0    0 Vice-President
 */
function us_legal_system ()
{     
	var game = new SimpleGame ();
	
	var president 	= new PlayerClass (1,   "President"),
		vice 		= new PlayerClass (1,   "Vice-President"),
		senators 	= new PlayerClass (100, "Member of the Senate"),
		reps 		= new PlayerClass (435, "Member of the House of Rep.");
	
	/* Add the (classes of) players. */
	game.addPlayerClass (senators);
	game.addPlayerClass (reps);
	game.addPlayerClass (president);
	game.addPlayerClass (vice);
	
	var factory = new RuleWVGFactory ();
	
	/* Add the rules. */
	game.createRule (factory, "presOnly").set2(1, [[president, 1]]);
	game.createRule (factory, "absMajSenate").set2(51, [[senators,1]]);
	game.createRule (factory, "absMajHouse").set2(218, [[reps,1]]);
	game.createRule (factory, "tieBreaker").set2(1, [[vice,1]])
	game.createRule (factory, "tieSenate").set2(50, [[senators, 1]]);
	game.createRule (factory, "twoThirdSenate").set2(67, [[senators, 1]]);
	game.createRule (factory, "twoThirdHouse").set2(290, [[reps, 1]]);
	
	game.setJoin ("presOnly & absMajSenate & absMajHouse "
			+"| presOnly & absMajHouse & tieBreaker & tieSenate "
			+"| twoThirdSenate & twoThirdHouse");
	
	return game;
}


/* [5;3,2,2,1] */
function simple_wvg_example ()
{
	var game = new SimpleGame ();
	
	var quota = 5;
	var mults = [1,2,1];
	var weights = [3,2,1];

	var classes = [];
	for (var i in mults) {
		var c = new PlayerClass (mults[i]);
		classes.push (c);
		game.addPlayerClass(c);
	}
	
	var rule = game.createRule (new RuleWVGFactory());
	rule.setQuota (quota);
	for (var i in classes) {
		rule.setWeightForClass (classes[i], weights[i]);
	}
	
	return game;
}

