/*
 * History.js
 *
 *  Copyright (C) 2011 Stefan Bolus, University of Kiel, Germany
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

/*
 * length
    Retrieves the number of key/value pairs in the list
key(index)
    Returns the key at the specified index
getItem(key)
    Returns the value associated with the given key
setItem(key, value)
    Sets a key/value pair
removeItem(key)
    Removes the item with the specified key
clear()
    Removes all key/value pairs
    */

/**
 * @class History 
 * 
 * Provides functionality to provide a history of games (text chunks) using
 * window.localStorage (Web Storage; DOM storage). See for instance
 * http://www.diveintojavascript.com/javascript-apis/web-storage-dom-storage
 */
function MyHistory ()
{
	/**
	 * ID of the next inserted entry.
	 */
	this.next_id = 0;
	
	this.ents = []; // id -> ent
	this.observers = [];
	
	// "hist:"+id -> {id,name,date(utc,milli),type(wvg,any),value}
	
	var i, key, ent;
	var key;
	for (i = 0 ; i < window.localStorage.length ; ++i) {
		key = window.localStorage.key(i);
		if (/hist:\d+/.test(key)) {
			ent = JSON.parse (window.localStorage.getItem(key));
			this.ents[ent.id] = ent;
			this.next_id = Math.max (parseInt(end.id, this.next_id));
		}
	}
	
	/**
	 * Callbacks are onStore(id) and onRemove(id)
	 */
	this.registerObserver = function (o) {
		this.observers.push(o);
	};
	
	/**
	 * Store a \ref WVG or an arbitrary simple game in form of a string. The
	 * user can assign a name to that game. Names don't have to be unique.
	 * 
	 * @tparam string name The game to save.
	 * @tparam string name Optional name string.
	 */
	this.store = function (game, name) {
		var id,name,type,value; 
		
		if ( !name) name = null;
		id = this.next_id++;
		value = game;
		date = new Date().getTime();
		
		var ent = { id: id, name: name, date: date, value: value };
		this.ents[id] = ent;
		window.localStorage.setItem ("hist:"+id, JSON.stringify(ent));
		
		for (var o in this.observers)
			if (this.observers[o].onStore)
				this.observers[o].onStore (id);
	};
	
	this.getEntries = function () {
		var ret = [];
		for (var id in this.ents)
			ret.push (this.ents[id]);
		return ret;
	};
	
	this.get = function (id) {
		return this.ents[id];
	};
	
	this.removeById = function (id) {
		for (var o in this.observers)
			if (this.observers[o].onRemove)
				this.observers[o].onRemove (id);
		
		delete this.ents[id];
		window.localStorage.removeItem ("hist:"+id);
	};
	
	this.clear = function () {
		this.ents = [];
		window.localStorage.clear();
	};
}
